@@ -62,7 +62,8 @@ class Sf:
         self.record_count: dict = {}
         self.record_count_caseinsensitive: dict = {}
         self.debug: bool = False
-        self.veeva_common = None
+        self.veeva_common:dict = None
+        self.org_info:dict = None
     
     def authenticate(self, sfUsername: Optional[str]=None, 
                                 sfPassword: Optional[str]=None, 
@@ -969,27 +970,34 @@ class Sf:
 
     def load_veeva_common(self):
         self.veeva_common = self.query("Select * From Veeva_Common_vod__c").to_dict()
+    
+    def load_org_info(self):
+        self.org_info = self.query("Select * From Organization").to_dict()
         
     def get_network_admin_sf_user_info(self):
-        sfOrgId = self.instance.split("--")[0]
         
         if self.veeva_common is None:
             self.load_veeva_common()
         
+        if self.org_info is None:
+            self.load_org_info()
+            
         try:
-            response = requests.get(f"{self.veeva_common['Veeva_Server_vod__c'][0]}/{self.veeva_common['Veeva_Version_vod__c'][0]}?VER={self.veeva_common['Veeva_Version_vod__c'][0]}&SSID={self.session_id}&url=https://{self.instance}/services/Soap/u/24.0/{sfOrgId}&ses={self.session_id}&oType=networkAdmin&event=getSFCredentials")
+            response = requests.get(f"{self.veeva_common['Veeva_Server_vod__c'][0]}/{self.veeva_common['Veeva_Version_vod__c'][0]}?VER={self.veeva_common['Veeva_Version_vod__c'][0]}&SSID={self.session_id}&url=https://{self.instance}/services/Soap/u/24.0/{self.org_info['Id'][0]}&ses={self.session_id}&oType=networkAdmin&event=getSFCredentials")
             return response.json()
         except:
             return {"error": "Unable to get network admin credentials"}
         
-    def get_network_admin_sf_user_info(self):
-        sfOrgId = self.instance.split("--")[0]
+    def get_network_admin_network_user_info(self):
         
         if self.veeva_common is None:
             self.load_veeva_common()
         
+        if self.org_info is None:
+            self.load_org_info()
+            
         try:
-            response = requests.get(f"{self.veeva_common['Veeva_Server_vod__c'][0]}/{self.veeva_common['Veeva_Version_vod__c'][0]}?VER={self.veeva_common['Veeva_Version_vod__c'][0]}&SSID={self.session_id}&url=https://{self.instance}/services/Soap/u/24.0/{sfOrgId}&ses={self.session_id}&oType=networkAdmin&event=getNetworkCredentials")
+            response = requests.get(f"{self.veeva_common['Veeva_Server_vod__c'][0]}/{self.veeva_common['Veeva_Version_vod__c'][0]}?VER={self.veeva_common['Veeva_Version_vod__c'][0]}&SSID={self.session_id}&url=https://{self.instance}/services/Soap/u/24.0/{self.org_info['Id'][0]}&ses={self.session_id}&oType=networkAdmin&event=getNetworkCredentials")
             return response.json()
         except:
             return {"error": "Unable to get network admin credentials"}
